@@ -32,6 +32,9 @@ class Stream_Enhancer:
     gain= (4,0) # 3 may be left??
     gamma= (5,0) # 3 may be left??
 
+    speedx= (6,0) #
+    speedy= (7,0) #
+
     #--------------------- 2 is bottom
     avg= (2,0) #
     blr= (2,1) #
@@ -90,6 +93,9 @@ class Stream_Enhancer:
         if row==4 and col==0:       return (50,50,50) #
         if row==5 and col==0:       return (80,80,80) #
 
+        if row==6 and col==0:       return (180,80,80) #
+        if row==7 and col==0:       return (80,180,80) #
+
         t=[255,255,255]
         while (t[0]+t[1]+t[2]>400) or  (t[0]+t[1]+t[2]<200) :
             t =  (randint(5,255),randint(5,255),randint(5,255) )
@@ -270,6 +276,9 @@ class Stream_Enhancer:
         if (row==4)and(col==0):  side="left"
         if (row==5)and(col==0):  side="left"
 
+        if (row==6)and(col==0):  side="left"
+        if (row==7)and(col==0):  side="left"
+
         if side=="" and row>2:
             print("X... Too many rows, (0,1,2 only)")
             return
@@ -321,7 +330,12 @@ class Stream_Enhancer:
         self.textbox(txt, pos , bgcolor= self.RC_COLOR(row,col) , target = target_frame)
 
 #-------------------------------------------- ENDOF LABELS----------
-
+    def save_background(self):
+        cv2.imwrite( self.BGFILE , self.frame )
+        self.frame_bg = self.frame
+        # frame_bg = self.frame.copy()
+        # frame_bg2 = cv2.imencode('.jpg', frame_bg)[1].tobytes()
+        # save_bg = False
 
     def subtract(self):
         if self.frame_bg is None:
@@ -332,16 +346,19 @@ class Stream_Enhancer:
                 return
         frame1 = cv2.subtract(self.frame , self.frame_bg ) #, mask = frame_mask
         # frame 1 is difference...
-        frame1[:22,:]  = self.frame [:22,:]
-        frame1[-22:,:] = self.frame [-22:,:]
+        # frame1[:22,:]  = self.frame [:22,:]
+        # frame1[-22:,:] = self.frame [-22:,:]
         self.frame = frame1
 
 
 
+    def reset_camera_start(self):
+        self.camera_start = dt.datetime.now()
+
     def translate(self, speedx = -0.35,  speedy = -0.015 ):
         self.camera_age = (dt.datetime.now() - self.camera_start ).total_seconds()
-        dwidth = -0.35 * self.camera_age  #negative up
-        dheight = -0.015 * self.camera_age  # positive down
+        dwidth = speedx * self.camera_age  #negative up
+        dheight = speedy * self.camera_age  # positive down
         T = np.float32([[1, 0, dwidth], [0, 1, dheight]])
         shifted = cv2.warpAffine(self.frame, T, (self.frame.shape[1], self.frame.shape[0]))
         # print( T )
